# csv2graph

## readOption

::: src.rdetoolkit.csv2graph.readOption

## _writeGraphImgFile_impl

::: src.rdetoolkit.csv2graph._writeGraphImgFile_impl

## writeGraphImgFile

::: src.rdetoolkit.csv2graph.writeGraphImgFile

## main

::: src.rdetoolkit.csv2graph.main
